==> cobalt-0.0.1-sources.jar: it/auties/whatsapp/model/message/payment/PaymentOrderMessageBuilder.java <==
package it.auties.whatsapp.model.message.payment;

public class PaymentOrderMessageBuilder {
    private java.lang.String id;
    private java.util.Optional<byte[]> thumbnail;
    private int itemCount;
    private it.auties.whatsapp.model.message.payment.PaymentOrderMessage.Status status;
    private it.auties.whatsapp.model.message.payment.PaymentOrderMessage.PaymentOrderSurface surface;
    private java.util.Optional<java.lang.String> message;
    private java.util.Optional<java.lang.String> title;
    private it.auties.whatsapp.model.jid.Jid sellerId;
    private java.lang.String token;
    private long amount;
    private java.lang.String currency;
    private java.util.Optional<it.auties.whatsapp.model.info.ContextInfo> contextInfo;

    public PaymentOrderMessageBuilder() {
        id = null;
        thumbnail = java.util.Optional.empty();
        itemCount = 0;
        status = null;
        surface = null;
        message = java.util.Optional.empty();
        title = java.util.Optional.empty();
        sellerId = null;
        token = null;
        amount = 0l;
        currency = null;
        contextInfo = java.util.Optional.empty();
    }

    public PaymentOrderMessageBuilder id(java.lang.String id) {
        this.id = id;
        return this;
    }
    public PaymentOrderMessageBuilder thumbnail(java.util.Optional<byte[]> thumbnail) {
        this.thumbnail = thumbnail;
        return this;
    }
    public PaymentOrderMessageBuilder thumbnail(byte[] thumbnail) {
        this.thumbnail = java.util.Optional.ofNullable(thumbnail);
        return this;
    }
    public PaymentOrderMessageBuilder itemCount(int itemCount) {
        this.itemCount = itemCount;
        return this;
    }
    public PaymentOrderMessageBuilder status(it.auties.whatsapp.model.message.payment.PaymentOrderMessage.Status status) {
        this.status = status;
        return this;
    }
    public PaymentOrderMessageBuilder surface(it.auties.whatsapp.model.message.payment.PaymentOrderMessage.PaymentOrderSurface surface) {
        this.surface = surface;
        return this;
    }
    public PaymentOrderMessageBuilder message(java.util.Optional<java.lang.String> message) {
        this.message = message;
        return this;
    }
    public PaymentOrderMessageBuilder message(java.lang.String message) {
        this.message = java.util.Optional.ofNullable(message);
        return this;
    }
    public PaymentOrderMessageBuilder title(java.util.Optional<java.lang.String> title) {
        this.title = title;
        return this;
    }
    public PaymentOrderMessageBuilder title(java.lang.String title) {
        this.title = java.util.Optional.ofNullable(title);
        return this;
    }
    public PaymentOrderMessageBuilder sellerId(it.auties.whatsapp.model.jid.Jid sellerId) {
        this.sellerId = sellerId;
        return this;
    }
    public PaymentOrderMessageBuilder token(java.lang.String token) {
        this.token = token;
        return this;
    }
    public PaymentOrderMessageBuilder amount(long amount) {
        this.amount = amount;
        return this;
    }
    public PaymentOrderMessageBuilder currency(java.lang.String currency) {
        this.currency = currency;
        return this;
    }
    public PaymentOrderMessageBuilder contextInfo(java.util.Optional<it.auties.whatsapp.model.info.ContextInfo> contextInfo) {
        this.contextInfo = contextInfo;
        return this;
    }
    public PaymentOrderMessageBuilder contextInfo(it.auties.whatsapp.model.info.ContextInfo contextInfo) {
        this.contextInfo = java.util.Optional.ofNullable(contextInfo);
        return this;
    }

    public it.auties.whatsapp.model.message.payment.PaymentOrderMessage build() {
        return new it.auties.whatsapp.model.message.payment.PaymentOrderMessage(id, thumbnail, itemCount, status, surface, message, title, sellerId, token, amount, currency, contextInfo);
    }
}

==> cobalt-0.0.2-sources.jar: it/auties/whatsapp/model/message/payment/PaymentOrderMessageBuilder.java <==
package it.auties.whatsapp.model.message.payment;

public class PaymentOrderMessageBuilder {
    private java.lang.String id;
    private byte[] thumbnail;
    private int itemCount;
    private it.auties.whatsapp.model.message.payment.PaymentOrderMessage.Status status;
    private it.auties.whatsapp.model.message.payment.PaymentOrderMessage.PaymentOrderSurface surface;
    private java.lang.String message;
    private java.lang.String title;
    private it.auties.whatsapp.model.jid.Jid sellerId;
    private java.lang.String token;
    private long amount;
    private java.lang.String currency;
    private it.auties.whatsapp.model.info.ContextInfo contextInfo;

    public PaymentOrderMessageBuilder() {
        id = null;
        thumbnail = null;
        itemCount = 0;
        status = null;
        surface = null;
        message = null;
        title = null;
        sellerId = null;
        token = null;
        amount = 0l;
        currency = null;
        contextInfo = null;
    }

    public PaymentOrderMessageBuilder id(java.lang.String id) {
        this.id = id;
        return this;
    }
    public PaymentOrderMessageBuilder thumbnail(byte[] thumbnail) {
        this.thumbnail = thumbnail;
        return this;
    }
    public PaymentOrderMessageBuilder itemCount(int itemCount) {
        this.itemCount = itemCount;
        return this;
    }
    public PaymentOrderMessageBuilder status(it.auties.whatsapp.model.message.payment.PaymentOrderMessage.Status status) {
        this.status = status;
        return this;
    }
    public PaymentOrderMessageBuilder surface(it.auties.whatsapp.model.message.payment.PaymentOrderMessage.PaymentOrderSurface surface) {
        this.surface = surface;
        return this;
    }
    public PaymentOrderMessageBuilder message(java.lang.String message) {
        this.message = message;
        return this;
    }
    public PaymentOrderMessageBuilder title(java.lang.String title) {
        this.title = title;
        return this;
    }
    public PaymentOrderMessageBuilder sellerId(it.auties.whatsapp.model.jid.Jid sellerId) {
        this.sellerId = sellerId;
        return this;
    }
    public PaymentOrderMessageBuilder token(java.lang.String token) {
        this.token = token;
        return this;
    }
    public PaymentOrderMessageBuilder amount(long amount) {
        this.amount = amount;
        return this;
    }
    public PaymentOrderMessageBuilder currency(java.lang.String currency) {
        this.currency = currency;
        return this;
    }
    public PaymentOrderMessageBuilder contextInfo(it.auties.whatsapp.model.info.ContextInfo contextInfo) {
        this.contextInfo = contextInfo;
        return this;
    }

    public it.auties.whatsapp.model.message.payment.PaymentOrderMessage build() {
        return new it.auties.whatsapp.model.message.payment.PaymentOrderMessage(id, thumbnail, itemCount, status, surface, message, title, sellerId, token, amount, currency, contextInfo);
    }
}
